@@ -14,7 +14,7 @@ Rcpp::List getCov(const Eigen::VectorXd & beta, const Eigen::VectorXd & gamma1,
                   const Eigen::MatrixXd & X1, const Eigen::VectorXd & Y, 
                   const Eigen::MatrixXd & X2, const Eigen::VectorXd & survtime, 
                   const Eigen::VectorXd & cmprsk, const Eigen::VectorXd & mdata, 
-                  const Eigen::VectorXd & mdataS,
+                  const Eigen::VectorXi & mdataS,
                   const Eigen::MatrixXd & FUNBS, 
                   const Eigen::MatrixXd & FUNEC, 
                   const Eigen::MatrixXd & FUNBEC,
